@@ -55,7 +55,7 @@ class Model(object):
     def __init__(self, model_ref):
         # Use _proto on read-only properties to use it's built-in type
         # conversion.
-        self._proto = types.Model()
+        self._proto = types.Model()._pb
 
         # Use _properties on read-write properties to match the REST API
         # semantics. The BigQuery API makes a distinction between an unset
@@ -151,13 +151,13 @@ class Model(object):
 
     @property
     def model_type(self):
-        """google.cloud.bigquery_v2.gapic.enums.Model.ModelType: Type of the
+        """google.cloud.bigquery_v2.types.Model.ModelType: Type of the
         model resource.
 
         Read-only.
 
         The value is one of elements of the
-        :class:`~google.cloud.bigquery_v2.gapic.enums.Model.ModelType`
+        :class:`~google.cloud.bigquery_v2.types.Model.ModelType`
         enumeration.
         """
         return self._proto.model_type
@@ -228,7 +228,7 @@ class Model(object):
 
     @property
     def friendly_name(self):
-        """Union[str, None]: Title of the table (defaults to :data:`None`).
+        """Optional[str]: Title of the table (defaults to :data:`None`).
 
         Raises:
             ValueError: For invalid value types.
@@ -241,7 +241,7 @@ class Model(object):
 
     @property
     def labels(self):
-        """Dict[str, str]: Labels for the table.
+        """Optional[Dict[str, str]]: Labels for the table.
 
         This method always returns a dict. To change a model's labels,
         modify the dict, then call ``Client.update_model``. To delete a
@@ -257,7 +257,7 @@ class Model(object):
 
     @property
     def encryption_configuration(self):
-        """google.cloud.bigquery.encryption_configuration.EncryptionConfiguration: Custom
+        """Optional[google.cloud.bigquery.encryption_configuration.EncryptionConfiguration]: Custom
         encryption configuration for the model.
 
         Custom encryption configuration (e.g., Cloud KMS keys) or :data:`None`
@@ -306,7 +306,7 @@ class Model(object):
             training_run["startTime"] = datetime_helpers.to_rfc3339(start_time)
 
         this._proto = json_format.ParseDict(
-            resource, types.Model(), ignore_unknown_fields=True
+            resource, types.Model()._pb, ignore_unknown_fields=True
         )
         return this
 
@@ -326,7 +326,7 @@ class ModelReference(object):
     """
 
     def __init__(self):
-        self._proto = types.ModelReference()
+        self._proto = types.ModelReference()._pb
         self._properties = {}
 
     @property
@@ -370,8 +370,9 @@ class ModelReference(object):
         # field values.
         ref._properties = resource
         ref._proto = json_format.ParseDict(
-            resource, types.ModelReference(), ignore_unknown_fields=True
+            resource, types.ModelReference()._pb, ignore_unknown_fields=True
         )
+
         return ref
 
     @classmethod
@@ -383,9 +384,9 @@ class ModelReference(object):
                 A model ID in standard SQL format. If ``default_project``
                 is not specified, this must included a project ID, dataset
                 ID, and model ID, each separated by ``.``.
-            default_project (str):
-                Optional. The project ID to use when ``model_id`` does not
-                include a project ID.
+            default_project (Optional[str]):
+                The project ID to use when ``model_id`` does not include
+                a project ID.
 
         Returns:
             google.cloud.bigquery.model.ModelReference:
